package com.junmp.jyzb.websocket;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.extra.spring.SpringUtil;
import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.junmp.iot.server.ws.WebSocketServerListener;
import com.junmp.iot.server.ws.impl.DefaultWebSocketServerMessage;
import com.junmp.iot.server.ws.impl.DefaultWebSocketServerProtocol;
import com.junmp.jyzb.api.util.WsCabinetReq;
import com.junmp.jyzb.cache.OnlineRedisCache;
import com.junmp.jyzb.entity.Cabinet;
import com.junmp.jyzb.entity.Temp.OnlineState;
import com.junmp.jyzb.service.CabinetService;
import com.junmp.jyzb.service.impl.CabinetServiceImpl;
import com.junmp.jyzb.utils.DateTimeUtil;
import com.junmp.v2.ws.api.enums.ClientMsgType;
import com.junmp.v2.ws.api.enums.ServerMsgType;
import com.junmp.v2.ws.api.enums.SysMsgTypeEnum;
import com.junmp.v2.ws.api.message.WsCallbackApi;
import com.junmp.v2.ws.api.session.bean.WsSession;
import com.junmp.v2.ws.bean.WsMsgDto;
import com.junmp.v2.ws.channel.WsSessionContainer;
import com.junmp.v2.ws.message.WsMessageHandle;
import com.junmp.v2.ws.session.WsSessionHandle;
import io.jsonwebtoken.JwtException;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.annotation.Order;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import javax.websocket.*;
import javax.websocket.server.PathParam;
import javax.websocket.server.ServerEndpoint;
import java.io.IOException;
import java.time.Instant;


 @Component
@Slf4j
public class CabinetWebSocketServer implements WebSocketServerListener {
     @Resource
     public CabinetService cabinetService;

    @Override
    public String uri() {
        return "/cabinet/ws";
    }

    @SneakyThrows
    @Override
    public void onText(DefaultWebSocketServerProtocol protocol) {
        String text = protocol.readText();
        ObjectMapper objectMapper = new ObjectMapper();
        WsCabinetReq boxData = objectMapper.readValue(text, WsCabinetReq.class);
       String channel=  protocol.requestMessage().getChannelId();
        Cabinet cabinet=cabinetService.getOne(new LambdaQueryWrapper<Cabinet>()
                .eq(Cabinet::getCabinetNum, boxData.getSerialNum()));
        cabinet.setOnlineState(1);
        cabinet.setUpdateTime(DateTimeUtil.getCurrentDateTime());
        cabinet.setChannelId(channel);
        cabinetService.updateById(cabinet);
        protocol.response("true");

    }

    @Override
    public void onClose(DefaultWebSocketServerProtocol protocol) {

       String channel= protocol.requestMessage().getChannelId();
        Cabinet cabinet=cabinetService.getOne(new LambdaQueryWrapper<Cabinet>()
                .eq(Cabinet::getChannelId, channel));
        cabinet.setOnlineState(0);
        cabinet.setChannelId("");
        cabinet.setUpdateTime(DateTimeUtil.getCurrentDateTime());
        cabinetService.updateById(cabinet);
        WebSocketServerListener.super.onClose(protocol);
    }

    @Override
    public void onBinary(DefaultWebSocketServerProtocol protocol) {
        WebSocketServerListener.super.onBinary(protocol);
    }
}